package com.fs.hisStore.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.hisStore.domain.FsUserOnlineStateScrm;

/**
 * 用户上线情况Service接口
 *
 * @author fs
 * @date 2025-06-30
 */
public interface IFsUserOnlineStateScrmService extends IService<FsUserOnlineStateScrm>{
    /**
     * 查询用户上线情况
     *
     * @param userId 用户上线情况主键
     * @return 用户上线情况
     */
    FsUserOnlineStateScrm selectFsUserOnlineStateById(Long userId);

    /**
     * 查询用户上线情况列表
     *
     * @param fsUserOnlineState 用户上线情况
     * @return 用户上线情况集合
     */
    List<FsUserOnlineStateScrm> selectFsUserOnlineStateList(FsUserOnlineStateScrm fsUserOnlineState);

    /**
     * 新增用户上线情况
     *
     * @param fsUserOnlineState 用户上线情况
     * @return 结果
     */
    int insertFsUserOnlineState(FsUserOnlineStateScrm fsUserOnlineState);

    /**
     * 修改用户上线情况
     *
     * @param fsUserOnlineState 用户上线情况
     * @return 结果
     */
    int updateFsUserOnlineState(FsUserOnlineStateScrm fsUserOnlineState);

    /**
     * 批量删除用户上线情况
     *
     * @param userIds 需要删除的用户上线情况主键集合
     * @return 结果
     */
    int deleteFsUserOnlineStateByIds(Long[] userIds);

    /**
     * 删除用户上线情况信息
     *
     * @param userId 用户上线情况主键
     * @return 结果
     */
    int deleteFsUserOnlineStateById(Long userId);

    /**
     * 统计未上线的用户（定时更新上线状态）
     */
    void insertUserNotOnline();

}
